# clear environment and load relevant libraries
rm(list=ls())
library(lme4)
library(lmerTest)

# load the data file (must be in the current directory)
Data = read.csv("Expt1_Data.csv")

# distributino of responses across conditions
round(prop.table(table(Data$Cond, Data$Attach),1),3)[,1:3]

# Deviation-code 3-level predictor with Cond = NS (narrative) as intercept reference
Data$DS = ifelse(Data$Cond=="DS",1,0)
Data$IS = ifelse(Data$Cond=="IS",1,0)

# Dummy-code the UC response (UC=unclassifiable)
Data$UC = ifelse(Data$Attach=="UC",1,0)

# fitting a glmm of UC to see if UC differs across conditions
m.UC = glmer(UC ~ DS + IS + (1 + DS + IS|Subj) + (1 + DS + IS|Item), data = Data, family=binomial(link="logit"))
summary(m.UC)
# results show that UC does not differ across conditions (ps>0.7)

# we thus exclude unclassifiable trials from analysis
Subdata = subset(Data, Data$Attach != "UC")

# distributino of responses across conditions
round(prop.table(table(Subdata$Cond, Subdata$Attach),1),3)[,1:2]

# Dummy-code the LA responses
Subdata$LA = ifelse(Subdata$Attach=="LA",1,0)

# fitting a glmm of LA
m.LA = glmer(LA ~ DS + IS + (1 + DS + IS|Subj) + (1 + DS + IS|Item), data = Subdata, family=binomial(link="logit"))
summary(m.LA)
# DS(-NS) effect was significant; IS effect was not significant.

# End of script